
# Testmetamodelmappings schema


Mappings test


### Classes

 * [C1](C1.md)
    * [C2](C2.md)
    * [C3](C3.md)

### Mixins


### Slots

 * [s1](s1.md)
 * [s2](s2.md)

### Types


#### Built in

 * **str**

#### Defined

 * [IdentifierType](types/IdentifierType.md)  ([String](types/String.md))  - A string that is intended to uniquely identify a thing May be URI in full or compact (CURIE) form
 * [String](types/String.md)  (**str**) 
